@@ -56,7 +56,8 @@ def _start(env):
     )
     if env['WEB_HOST'].lower() == 'localhost':
         click.echo(
-            '\nWARNING: you\'re running Teamplify on localhost. This is '
+            click.style('\nWARNING:', fg='yellow') +
+            ' you\'re running Teamplify on localhost. This is '
             'probably OK if you only need to run a demo on your local machine. '
             'However, in this mode it will not be available to anyone from the '
             'network. If you\'d like to make it available on the network, you '
